pick_by_name

Function pick_by_name 

pub fn pick_by_name(name: &str) -> Option<Box<dyn PackageManager>>
Return the manager with the given name regardless of availability.

Returns None when no manager with that name is registered.