pub fn pick_default() -> Option<Box<dyn PackageManager>>Expand description
Return the first available manager for the current platform.
pub fn pick_default() -> Option<Box<dyn PackageManager>>Return the first available manager for the current platform.