pub fn pick_by_name(name: &str) -> Option<Box<dyn PackageManager>>Expand description
Return the manager with the given name regardless of availability.
Returns None when no manager with that name is registered.
pub fn pick_by_name(name: &str) -> Option<Box<dyn PackageManager>>Return the manager with the given name regardless of availability.
Returns None when no manager with that name is registered.