Core PackageManager and Runner traits plus production/test impls.
Structs
- Mock
Response - Scripted response for one call.
- Mock
Runner - Test runner that records every call and returns scripted responses.
- Real
Runner - Production runner — spawns a child process via
Command. - RunOutcome
- Result of a single process invocation.
Enums
- Package
Error - Errors produced by package manager operations.
Traits
- Package
Manager - Abstraction over a system package manager.
- Runner
- Abstraction over process execution so tests can verify behaviour without invoking real system commands.