Module winget

Module winget 

winget package manager implementation (Windows Package Manager).

winget does not reliably accept multiple packages in one call, so each package is installed in a separate process invocation.

Structs

Winget
Package manager implementation for Windows (winget).